(* create an ldap entry factory from a channel attached to 
an ldif source default is stdin and stdout. *)
class ldif: 
  ?in_ch:Pervasives.in_channel -> 
  ?out_ch:Pervasives.out_channel -> 
  unit ->
object
  method read_entry: Ooldap.ldapentry
  method of_string: string -> Ooldap.ldapentry
  method to_string: Ooldap.ldapentry -> string
  method write_entry: Ooldap.ldapentry -> unit
end
